==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_shipping.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_shipping.lang.inc.php 2019-05-10
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'FREE_SHIPPING_DESCRIPTION'                            => 'Versandkostenfrei ab einem Bestellwert von %s',
    'FREE_SHIPPING_TITLE'                                  => 'Versandkostenfrei',
    'MODULE_ORDER_TOTAL_SHIPPING_DESCRIPTION'              => 'Versandkosten einer Bestellung',
    'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION_DESC'         => 'Versandkostenfrei nach Zonen berechnen.',
    'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION_TITLE'        => 'Versandkostenfrei nach Zonen',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_DESC'       => 'Versandkostenfreie Lieferung erlauben ?',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER_DESC'  => 'Geben Sie hier die Versandkostenfreigrenze (brutto) ein. Für die Nettoumrechnung wird die unten angegebene Steuerklasse genutzt.',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER_TITLE' => 'Versandkostenfreigrenze',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_TITLE'      => 'Versandkostenfrei erlauben',
    'MODULE_ORDER_TOTAL_SHIPPING_SHOW_TITLE_DESC'          => 'Genaue Versandinformationen im Warenkorb anzeigen',
    'MODULE_ORDER_TOTAL_SHIPPING_SHOW_TITLE_TITLE'         => 'Versandmodulinformationen',
    'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER_DESC'          => 'Anzeigereihenfolge.',
    'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER_TITLE'         => 'Sortierreihenfolge',
    'MODULE_ORDER_TOTAL_SHIPPING_STATUS_DESC'              => 'Anzeige der Versandkosten?',
    'MODULE_ORDER_TOTAL_SHIPPING_STATUS_TITLE'             => 'Versandkosten',
    'MODULE_ORDER_TOTAL_SHIPPING_TAX_CLASS_DESC'           => 'Folgende Steuerklasse für die Versandkosten wählen (Nur für Bestellbearbeitung und Nettoumrechnung der Versandkostenfreigrenze)',
    'MODULE_ORDER_TOTAL_SHIPPING_TAX_CLASS_TITLE'          => 'Steuerklasse',
    'MODULE_ORDER_TOTAL_SHIPPING_TITLE'                    => 'Versandkosten',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/order_total/ot_shipping.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	ot_shipping.lang.inc.php 2019-05-10
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'FREE_SHIPPING_DESCRIPTION'                            => 'Versandkostenfrei ab einem Bestellwert von %s',
    'FREE_SHIPPING_TITLE'                                  => 'Versandkostenfrei',
    'MODULE_ORDER_TOTAL_SHIPPING_DESCRIPTION'              => 'Versandkosten einer Bestellung',
    'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION_DESC'         => 'Versandkostenfrei nach Zonen berechnen.',
    'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION_TITLE'        => 'Versandkostenfrei nach Zonen',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_DESC'       => 'Versandkostenfreie Lieferung erlauben ?',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER_DESC'  => 'Gib hier die Versandkostenfreigrenze (brutto) ein. Für die Nettoumrechnung wird die unten angegebene Steuerklasse genutzt.',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER_TITLE' => 'Versandkostenfreigrenze',
    'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_TITLE'      => 'Versandkostenfrei erlauben',
    'MODULE_ORDER_TOTAL_SHIPPING_SHOW_TITLE_DESC'          => 'Genaue Versandinformationen im Warenkorb anzeigen',
    'MODULE_ORDER_TOTAL_SHIPPING_SHOW_TITLE_TITLE'         => 'Versandmodulinformationen',
    'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER_DESC'          => 'Anzeigereihenfolge.',
    'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER_TITLE'         => 'Sortierreihenfolge',
    'MODULE_ORDER_TOTAL_SHIPPING_STATUS_DESC'              => 'Anzeige der Versandkosten?',
    'MODULE_ORDER_TOTAL_SHIPPING_STATUS_TITLE'             => 'Versandkosten',
    'MODULE_ORDER_TOTAL_SHIPPING_TAX_CLASS_DESC'           => 'Folgende Steuerklasse für die Versandkosten wählen (Nur für Bestellbearbeitung und Nettoumrechnung der Versandkostenfreigrenze)',
    'MODULE_ORDER_TOTAL_SHIPPING_TAX_CLASS_TITLE'          => 'Steuerklasse',
    'MODULE_ORDER_TOTAL_SHIPPING_TITLE'                    => 'Versandkosten',
];
